.. pm4py documentation master file, created by
   sphinx-quickstart on Fri Aug 24 10:06:48 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pm4py's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. automodule:: pm4py


Indices and tables
==================

.. * :ref:`genindex`
* :ref:`modindex`
.. * :ref:`search`
